@@ -32,9 +32,11 @@ impl SqlDialect {
         }
     }
 
-    fn tokenize(&self, query: &str) -> Vec<Token> {
+    fn tokenize(&self, query: &str) -> Result<Vec<Token>, &'static str> {
         let dialect = self.sqlparser_dialect();
-        Tokenizer::new(&*dialect, query).tokenize().unwrap()
+        Tokenizer::new(&*dialect, query)
+            .tokenize()
+            .or(Err("Failed to tokenize query"))
     }
 }
 
@@ -43,8 +45,8 @@ pub struct Parser {
 }
 
 impl Parser {
-    pub fn try_new(sql_dialect: SqlDialect, query: &str) -> Result<Self, &str> {
-        let tokens = sql_dialect.tokenize(query);
+    pub fn try_new(sql_dialect: SqlDialect, query: &str) -> Result<Self, &'static str> {
+        let tokens = sql_dialect.tokenize(query)?;
         let query =
             sqlparser::parser::Parser::new(tokens, &*sql_dialect.sqlparser_dialect()).parse_query();
         match query {
@@ -215,13 +217,13 @@ fn from_expr(expr: &Expr) -> Vec<&str> {
                 let separator_res = from_expr(separator);
                 expr_res.extend(separator_res);
             }
-            if let Some(on_overflow) = on_overflow {
-                if let ListAggOnOverflow::Truncate { filler, .. } = on_overflow {
-                    if let Some(filler) = filler {
-                        let on_overflow_res = from_expr(filler);
-                        expr_res.extend(on_overflow_res);
-                    }
-                }
+            if let Some(ListAggOnOverflow::Truncate {
+                filler: Some(filler),
+                ..
+            }) = on_overflow
+            {
+                let on_overflow_res = from_expr(filler);
+                expr_res.extend(on_overflow_res);
             }
             expr_res
         }
@@ -273,7 +275,7 @@ fn from_select(select: &Select) -> Vec<&str> {
     }
 
     if let Some(selection) = &select.selection {
-        let selection_res = from_expr(&selection);
+        let selection_res = from_expr(selection);
         projection_res.extend(selection_res);
     }
 
